@@ -3,6 +3,7 @@
 import os
 import sys
 import shutil
+from pathlib import Path
 from distutils.util import strtobool
 
 
@@ -40,10 +41,8 @@ def query_yes_no(question, default="yes"):
         else:
             try:
                 return bool(strtobool(choice))
-            except:
-                sys.stdout.write(
-                    "Please respond with 'yes' or 'no' " "(or 'y' or 'n').\n"
-                )
+            except:  # noqa
+                sys.stdout.write("Please respond with 'yes' or 'no' " "(or 'y' or 'n').\n")
 
 
 def query_continue(question, default="no"):
@@ -67,7 +66,7 @@ def query_continue(question, default="no"):
         return answer
 
 
-def check_data_path(data_path):
+def check_data_path(data_path, glob=None):
     """
     Check if the path to some data exists.
     Raise an Error if the path does not exist, is not a directory or does not contain data.
@@ -75,32 +74,36 @@ def check_data_path(data_path):
     Parameters
     ----------
     data_path: str
+    glob: str
+        Glob pattern to be passed
     """
-    if not os.path.exists(data_path):
-        raise ValueError("The input directory must exist")
-    if get_input_filelist(data_path) == []:
-        raise ValueError("The input directory is empty")
-    # if not data_path.startswith(BASE_DIR):
-    #     raise ValueError("The root directory for the data is supposed to be {}".format(BASE_DIR))
+    if not Path(data_path).exists():
+        raise ValueError(f"The input directory {data_path} must exist")
+    if not get_input_filelist(data_path, glob_pattern=glob):
+        raise ValueError(f"The input directory {data_path} is empty")
 
 
-def get_input_filelist(data_path):
+def get_input_filelist(data_path, glob_pattern=None):
     """
     Return list of files in `data_path`
 
     Parameters
     ----------
     data_path: str
+        Directory path
+    glob_pattern: str
+        Glob the given pattern. To Glob recursively, add "**/" in front of the string
 
     Returns
     -------
-    list of str
+    list
     """
-    return [
-        os.path.abspath(os.path.join(data_path, f))
-        for f in os.listdir(data_path)
-        if os.path.isfile(os.path.join(data_path, f))
-    ]
+    if glob_pattern is None:
+        _path = Path(data_path).iterdir()
+    else:
+        _path = Path(data_path).glob(str(glob_pattern))
+
+    return [file.resolve().as_posix() for file in _path]
 
 
 def check_and_make_dir(directory):
@@ -115,9 +118,7 @@ def check_and_make_dir(directory):
     """
     if os.path.exists(directory) and os.listdir(directory) != []:
         clean = query_continue(
-            "The directory {} is not empty. Do you want to remove its content?".format(
-                directory
-            ),
+            "The directory {} is not empty. Do you want to remove its content?".format(directory),
             default="no",
         )
         if clean:
