@@ -84,10 +84,7 @@ def create_log_files(production_id):
         backup_log(debug_file)
         debug_file.unlink()
 
-    logs_files = {
-        "log_file": log_file,
-        "debug_file": debug_file
-    }
+    logs_files = {"log_file": log_file, "debug_file": debug_file}
 
     return logs_files, scancel_file, lstmcpipe_log_dir
 
