@@ -9,13 +9,9 @@ from lstchain.visualization.plot_dl2 import plot_models_features_importances
 
 
 def main():
-    parser = argparse.ArgumentParser(
-        description="Plot features importance from trained random forests models"
-    )
+    parser = argparse.ArgumentParser(description="Plot features importance from trained random forests models")
     parser.add_argument("models_path", help="path to the trained models")
-    parser.add_argument(
-        "--config_file", "-cf", default=None, help="Path to the config file. Optional."
-    ),
+    parser.add_argument("--config_file", "-cf", default=None, help="Path to the config file. Optional."),
     args = parser.parse_args()
 
     plot_models_features_importances(args.models_path, config_file=args.config_file)
